<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.expertrec.com/
 * @since             1.0.0
 * @package           Expertrecsearch
 *
 * @wordpress-plugin
 * Plugin Name:       ExpertRec
 * Plugin URI:        https://www.expertrec.com/
 * Description:       Expertrec Search replaces your site search functionality with a fast <strong>Google like search</strong>.  It totally <strong>avoids the load on your wordpress server</strong> when your users are searching.
 * Version:           2.1.0
 * Author:            Expertrec
 * Author URI:        https://www.expertrec.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       expertrecsearch
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PLUGIN_NAME_VERSION', '2.3.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-expertrecsearch-activator.php
 */
function activate_expertrecsearch() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-expertrecsearch-activator.php';
	Expertrecsearch_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-expertrecsearch-deactivator.php
 */
function deactivate_expertrecsearch() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-expertrecsearch-deactivator.php';
	Expertrecsearch_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_expertrecsearch' );
register_deactivation_hook( __FILE__, 'deactivate_expertrecsearch' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-expertrecsearch.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_expertrecsearch() {

	$plugin = new Expertrecsearch();
	$plugin->run();

}
run_expertrecsearch();
